@@ -26,6 +26,7 @@ SITES = {
     'heavy-music'      : 'heavymusic',
     'iask'             : 'sina',
     'ifeng'            : 'ifeng',
+    'imgur'            : 'imgur',
     'in'               : 'alive',
     'instagram'        : 'instagram',
     'interest'         : 'interest',
@@ -63,7 +64,9 @@ SITES = {
     'tucao'            : 'tucao',
     'tudou'            : 'tudou',
     'tumblr'           : 'tumblr',
+    'twimg'            : 'twitter',
     'twitter'          : 'twitter',
+    'videomega'        : 'videomega',
     'vidto'            : 'vidto',
     'vimeo'            : 'vimeo',
     'weibo'            : 'miaopai',
